avatars.manager.Manager
=======================

.. currentmodule:: avatars.manager

.. autoclass:: Manager


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~Manager.__init__
      ~Manager.authenticate
      ~Manager.create_runner
      ~Manager.create_runner_from_yaml
      ~Manager.forgotten_password
      ~Manager.get_health
      ~Manager.get_last_jobs
      ~Manager.get_last_results
      ~Manager.reset_password
